@@ -3,6 +3,7 @@ import sys
 import stat
 import backstage
 import subprocess
+from backstage.utils import uwsgi_portsniffer
 
 class Venue():
     """A backstage Venue is a specific local install of backstage."""
@@ -119,7 +120,7 @@ class Venue():
         except IOError:
             print 'Could not update, permission denied.'
             return
-        self.get_uwsgi_port()
+        self.uwsgi_ip, self.uwsgi_port = uwsgi_portsniffer.get_uwsgi_port(self.UWSGI_INI)
         return
 
 
